@@ -15,17 +15,25 @@ class Interpolator:
 
     # Import the trajectory and parse it for interpolation
     def import_traj(self, trajectory):
-        prefix = np.array(trajectory['prefix'])
-        suffix = np.array(trajectory['suffix'])
+        prefix = trajectory['prefix']
+        suffix = trajectory['suffix']
+
+        if prefix is not None:
+            prefix = np.array(prefix)
+            self.prefix =  {'time' : prefix[:,0]  ,
+                            'values': prefix[:,1:]  }
+        else:
+            self.prefix = None
+
+
+        if suffix is not None:
+            suffix = np.array(suffix)
+            self.suffix =  {'time' : suffix[:,0]  ,
+                            'values': suffix[:,1:]  }
+        else:
+            self.suffix =  None
+
         main   = np.array(trajectory['setpoints'])
-
-
-        self.prefix =  {'time' : prefix[:,0]  ,
-                        'values': prefix[:,1:]  }
-
-        self.suffix =  {'time' : suffix[:,0]  ,
-                        'values': suffix[:,1:]  }
-
         self.main =    {'time' : main[:,0]  ,
                         'values': main[:,1:]  }
 
@@ -56,12 +64,14 @@ class Interpolator:
         values = np.insert(values, 0, self.main['values'][0,:], axis=0)
 
         # Insert the prefix and suffix
-        times=times+self.prefix['time'][-1]
-        times = np.insert(times, range(self.prefix['time'].shape[0]), self.prefix['time'], axis=0)
-        times = np.append(times, self.suffix['time']+times[-1], axis=0)
+        if self.prefix is not None:
+            times=times+self.prefix['time'][-1]
+            times = np.insert(times, range(self.prefix['time'].shape[0]), self.prefix['time'], axis=0)
+            values = np.insert(values, range(self.prefix['values'].shape[0]), self.prefix['values'], axis=0)
 
-        values = np.insert(values, range(self.prefix['values'].shape[0]), self.prefix['values'], axis=0)
-        values = np.append(values, self.suffix['values'], axis=0)
+        if self.suffix is not None:
+            times = np.append(times, self.suffix['time']+times[-1], axis=0)
+            values = np.append(values, self.suffix['values'], axis=0)
 
         self.final_time = times[-1]
 
@@ -83,11 +93,20 @@ class Interpolator:
 
         return self.interp_fun
 
+
+    # Generate a function to return the current cycle number given times
     def get_cycle_function(self, num_reps=1, speed_factor = 1.0, invert_direction=False, as_list=False):
 
+        if self.prefix is not None:
+            prefix_dur = self.prefix['time'][-1]
+        else:
+            prefix_dur = 0.0
+
+        if self.suffix is not None:
+            suffix_dur = self.suffix['time'][-1]
+        else:
+            suffix_dur = 0.0
 
-        prefix_dur = self.prefix['time'][-1]
-        suffix_dur = self.suffix['time'][-1]
         main_dur = self.main['time'][-1]
         total_main_dur = main_dur/speed_factor*num_reps
 
